pub struct Reservation {
pub kind: String,
pub name: Option<String>,
pub reservation_id: Option<String>,
pub status: Option<String>,
pub start_date: Option<String>,
pub end_date: Option<String>,
pub location: Option<String>,
pub provider: Option<String>,
pub departure_airport: Option<String>,
pub arrival_airport: Option<String>,
pub flight_number: Option<String>,
}Expand description
One reservation (flight, hotel, restaurant, rental car, etc).
Fields
kind: StringReservation kind: flight / hotel / restaurant / rental_car.
name: Option<String>Display name (hotel name, restaurant name, etc).
reservation_id: Option<String>Reservation confirmation code.
status: Option<String>Status string (confirmed / cancelled / pending).
start_date: Option<String>ISO-8601 start date / time.
end_date: Option<String>ISO-8601 end date / time.
location: Option<String>Location (address / city / airport).
provider: Option<String>Provider / brand (airline, hotel chain, etc).
departure_airport: Option<String>IATA code or name of the departure airport (flight only).
arrival_airport: Option<String>IATA code or name of the arrival airport (flight only).
flight_number: Option<String>Flight number (flight only).